.. index:: Murano Administrator Guide

.. _admin-guide:

Deploying Murano
~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 2

   deploy_murano
   prepare_lab
   murano_policies
   manage_packages
   manage_images
   manage_categories
   murano_repository
   murano_agent
   policy_enf
   using_glare.rst
   net_configuration
   configure_cloud_foundry_service_broker
   admin_troubleshooting
   appdev-guide/developer_index
   config-wsgi
